@@ -154,7 +154,7 @@ class Downloader:
                 await self.File_Lock.add_lock(filename)
 
                 complete_file = (self.folder / self.title / filename)
-                partial_file = (self.folder / self.title / filename)
+                partial_file = complete_file.with_suffix(complete_file.suffix + '.part')
 
                 if complete_file.exists() or partial_file.exists():
                     if complete_file.exists():
@@ -181,8 +181,8 @@ class Downloader:
                 await self.SQL_helper.sql_insert_file(db_path, filename, 0)
 
                 complete_file = (self.folder / self.title / filename)
-                resume_point = 0
                 temp_file = complete_file.with_suffix(complete_file.suffix + '.part')
+                resume_point = 0
 
                 range = None
                 if temp_file.exists():
@@ -263,9 +263,9 @@ class Downloader:
         for func in tqdm(asyncio.as_completed(coros), total=len(coros), desc=self.title, unit='FILES'):
             await func
 
-    async def download_content(self, show_progress: bool = True) -> None:
+    async def download_content(self, show_progress: bool = True, conn_timeout: int = 15) -> None:
         """Download the content of all links and save them as files."""
-        session = DownloadSession(self.client)
+        session = DownloadSession(self.client, conn_timeout)
         await self.download_all(self.album_obj, session, show_progress=show_progress)
         self.SQL_helper.conn.commit()
 
